@@ -97,6 +97,14 @@ as.na <- function(x, as.na, check = TRUE) {
 
   }
 
+  #......
+  # Check if input 'x' is NULL
+  if (is.null(x)) {
+
+    stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
+
+  }
+
   #......
   # Check if input 'as.na' is missing
   if (missing(as.na)) {
@@ -106,9 +114,17 @@ as.na <- function(x, as.na, check = TRUE) {
 
   }
 
+  #......
+  # Check if input 'as.na' is NULL
+  if (is.null(as.na)) {
+
+    stop("Input specified for the argument 'as.na' is NULL.", call. = FALSE)
+
+  }
+
   #......
   # Check input 'check'
-  if (isFALSE(isTRUE(check) || isFALSE(check))) {
+  if (!isTRUE(isTRUE(check) || !isTRUE(check))) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
