@@ -112,13 +112,21 @@ ci.var <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided"
 
   #......
   # Check if input 'x' is missing
-  if (missing(x) || is.null(x)) {
+  if (missing(x)) {
 
     stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.",
          call. = FALSE)
 
   }
 
+  #......
+  # Check if input 'x' is NULL
+  if (is.null(x)) {
+
+    stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
+
+  }
+
   #......
   # Vector, matrix or data frame for the argument 'x'?
   if (!is.atomic(x) && !is.matrix(x) && !is.data.frame(x)) {
@@ -252,7 +260,7 @@ ci.var <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided"
 
   #......
   # Check input 'check'
-  if (isFALSE(isTRUE(check) || isFALSE(check))) {
+  if (!isTRUE(isTRUE(check) || !isTRUE(check))) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -282,7 +290,7 @@ ci.var <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided"
 
     #......
     # Check input 'conf.level'
-    if (conf.level >= 1L|| conf.level <= 0L) {
+    if (conf.level >= 1L || conf.level <= 0L) {
 
       stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.",
            call. = FALSE)
@@ -379,7 +387,7 @@ ci.var <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided"
 
     #......
     # Check input 'sort.var'
-    if (isFALSE(isTRUE(sort.var) || isFALSE(sort.var))) {
+    if (!isTRUE(isTRUE(sort.var) || !isTRUE(sort.var))) {
 
       stop("Please specify TRUE or FALSE for the argument 'sort.var'.", call. = FALSE)
 
@@ -387,7 +395,7 @@ ci.var <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided"
 
     #......
     # Check input 'na.omit'
-    if (isFALSE(isTRUE(na.omit) || isFALSE(na.omit))) {
+    if (!isTRUE(isTRUE(na.omit) || !isTRUE(na.omit))) {
 
       stop("Please specify TRUE or FALSE for the argument 'na.omit'.", call. = FALSE)
 
@@ -403,7 +411,7 @@ ci.var <- function(x, method = c("chisq", "bonett"), alternative = c("two.sided"
 
     #......
     # Check input output
-    if (isFALSE(isTRUE(output) || isFALSE(output))) {
+    if (!isTRUE(isTRUE(output) || !isTRUE(output))) {
 
       stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
 
