@@ -115,9 +115,17 @@ rwg.lindell <- function(x, group, A = NULL, ranvar = NULL, z = TRUE, expand = TR
 
   }
 
+  #......
+  # Check if input 'x' is NULL
+  if (is.null(x)) {
+
+    stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
+
+  }
+
   #......
   # Check input 'check'
-  if (isFALSE(isTRUE(check) || isFALSE(check))) {
+  if (!isTRUE(isTRUE(check) || !isTRUE(check))) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -183,7 +191,7 @@ rwg.lindell <- function(x, group, A = NULL, ranvar = NULL, z = TRUE, expand = TR
 
     #......
     # Check input 'z'
-    if (isFALSE(isTRUE(z) || isFALSE(z))) {
+    if (!isTRUE(isTRUE(z) || !isTRUE(z))) {
 
       stop("Please specify TRUE or FALSE for the argument 'z'.", call. = FALSE)
 
@@ -191,7 +199,7 @@ rwg.lindell <- function(x, group, A = NULL, ranvar = NULL, z = TRUE, expand = TR
 
     #......
     # Check input 'expand'
-    if (isFALSE(isTRUE(expand) || isFALSE(expand))) {
+    if (!isTRUE(isTRUE(expand) || !isTRUE(expand))) {
 
       stop("Please specify TRUE or FALSE for the argument 'expand'.", call. = FALSE)
 
